%define module	pyzmq

# disable test on BS, but ok on local iurt
%global run_tests 0

Summary:	Python bindings for zeromq
Name:		python-%{module}
Version:	23.2.1
Release:	%mkrel 1
License:	LGPLv3+ and ASL 2.0 and BSD
Group:		Development/Python
Url:		https://github.com/zeromq/pyzmq
Source0:	https://pypi.io/packages/source/p/%{module}/%{module}-%{version}.tar.gz
BuildRequires:	chrpath
BuildRequires:	pkgconfig(libzmq)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(nose)
BuildRequires:	python3dist(cython)

# test
%if 0%{?run_tests}
BuildRequires:	python3-tornado
%endif

%description
This package contains Python bindings for zeromq, a lightweight and
fast messaging implementation.

%package -n python3-%{module}
Summary:	Software library for fast, message-based applications
Group:		Development/Python
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

This package contains the python 3 bindings.

%prep
%setup -q -n %{module}-%{version}

# remove bundled libraries
rm -rf bundled
for lib in zmq/eventloop/*.py; do
    sed '/\/usr\/bin\/env/d' $lib > $lib.new &&
    touch -r $lib $lib.new &&
    mv $lib.new $lib
done

# remove excecutable bits
chmod -x examples/pubsub/topics_pub.py
chmod -x examples/pubsub/topics_sub.py

%build
%py3_build

%install
%py3_install

chrpath --delete %{buildroot}%{python3_sitearch}/zmq/{backend/cython,devices}/*.so

%if 0%{?run_tests}
%check
   %{__rm} -f zmq/__*
   PYTHONPATH=%{buildroot}%{python3_sitearch} \
    %{__python3} setup.py test
   %{__rm} -rf %{buildroot}%{python3_sitearch}/zmq/tests
%endif

%files -n python3-%{module}
%doc README.md COPYING.*
# examples/
%{python3_sitearch}/%{module}-*.egg-info
%{python3_sitearch}/zmq


%changelog
* Thu Sep 08 2022 neoclust <neoclust> 23.2.1-1.mga9
+ Revision: 1885918
- New version 23.2.1

* Sun Apr 17 2022 joequant <joequant> 22.3.0-1.mga9
+ Revision: 1850910
- update to 22.3.0

* Sat Apr 02 2022 umeabot <umeabot> 22.0.3-3.mga9
+ Revision: 1840977
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 22.0.3-2.mga9
+ Revision: 1775155
- rebuild for python-3.10

* Tue Mar 23 2021 daviddavid <daviddavid> 22.0.3-1.mga9
+ Revision: 1708150
- new version: 22.0.3

* Tue Mar 23 2021 daviddavid <daviddavid> 19.0.2-2.mga9
+ Revision: 1708149
- rebuild for python 3.9

* Thu Aug 20 2020 joequant <joequant> 19.0.2-1.mga8
+ Revision: 1616692
- update to 19.0.2

* Sun Feb 16 2020 umeabot <umeabot> 17.0.0-6.mga8
+ Revision: 1532187
- Mageia 8 Mass Rebuild

* Mon Sep 16 2019 daviddavid <daviddavid> 17.0.0-5.mga8
+ Revision: 1441923
- rebuild for python3.8
- drop python2 support

* Thu Jan 17 2019 barjac <barjac> 17.0.0-4.mga7
+ Revision: 1357695
- rebuild for zeromq
- tidy tabs/spaces in spec

* Mon Jan 07 2019 wally <wally> 17.0.0-3.mga7
+ Revision: 1350967
- rebuild for python3.7

* Sun Sep 23 2018 umeabot <umeabot> 17.0.0-2.mga7
+ Revision: 1300581
- Mageia 7 Mass Rebuild

* Thu Apr 05 2018 kekepower <kekepower> 17.0.0-1.mga7
+ Revision: 1215398
- Update to version 17.0.0
- Renamed python-pyzmq to python2-pyzmq

* Sat Aug 05 2017 pterjan <pterjan> 15.2.0-3.mga7
+ Revision: 1135595
- Rebuild for python 3.6

* Sat Mar 05 2016 philippem <philippem> 15.2.0-2.mga6
+ Revision: 986119
- update sources to 15.2.0, clean spec

* Sat Mar 05 2016 philippem <philippem> 15.2.0-1.mga6
+ Revision: 986107
- update to 15.2.0, disable test on BS

* Tue Feb 16 2016 umeabot <umeabot> 15.0.0-3.mga6
+ Revision: 962422
- Mageia 6 Mass Rebuild

* Wed Nov 18 2015 joequant <joequant> 15.0.0-2.mga6
+ Revision: 903951
- upgrade to 15.0.0

* Wed Oct 07 2015 philippem <philippem> 14.7.0-2.mga6
+ Revision: 887170
- rebuild for Python3.5

* Wed Aug 19 2015 joequant <joequant> 14.7.0-1.mga6
+ Revision: 865836
- upgrade to 14.7.0

* Wed Aug 19 2015 joequant <joequant> 14.3.1-6.mga6
+ Revision: 865827
- update to libpyzmq5

* Mon Nov 17 2014 barjac <barjac> 14.3.1-5.mga5
+ Revision: 797628
- rebuild for new zeromq

* Wed Oct 15 2014 umeabot <umeabot> 14.3.1-4.mga5
+ Revision: 749943
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 14.3.1-3.mga5
+ Revision: 729613
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Wed Jul 30 2014 barjac <barjac> 14.3.1-1.mga5
+ Revision: 658114
-new version 14.3.1
- rebuild for new zeromq-4.0.4

* Mon Jun 02 2014 philippem <philippem> 14.3.0-1.mga5
+ Revision: 630651
- update to 14.3.0
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 13.1.0-3.mga4
+ Revision: 544242
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 13.1.0-2.mga4
+ Revision: 499281
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Aug 16 2013 philippem <philippem> 13.1.0-1.mga4
+ Revision: 467030
- fix wrong group
- update to 13.1.0, add Python 3

* Sat Jun 08 2013 fwang <fwang> 2.2.0.1-2.mga4
+ Revision: 440438
- drop invalid req

* Sat Jun 08 2013 fwang <fwang> 2.2.0.1-1.mga4
+ Revision: 440417
- add req for testing
- new version 2.2.0.1

* Sun Jan 13 2013 umeabot <umeabot> 2.1.9-4.mga3
+ Revision: 379424
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 21 2011 lebedov <lebedov> 2.1.9-3.mga2
+ Revision: 146196
- Bump release.

* Wed Sep 21 2011 lebedov <lebedov> 2.1.9-2.mga2
+ Revision: 146188
- Require zeromq library with the same version as pyzmq (or later).

* Sun Sep 18 2011 lebedov <lebedov> 2.1.9-1.mga2
+ Revision: 145119
- Update source file.
- Update to 2.1.9.

* Thu Apr 14 2011 mikala <mikala> 2.1.4-1.mga1
+ Revision: 85343
- Update to 2.1.4 to match zeromq 2.1.4

* Mon Jan 31 2011 dmorgan <dmorgan> 2.0.10_1-1.mga1
+ Revision: 45303
- imported package python-pyzmq


* Sun Jan 30 2011 Lev Givon <lev@mandriva.org> 2.0.10_1-1mdv2011.0
+ Revision: 634029
- Update to 2.0.10-1.

* Tue Nov 16 2010 Lev Givon <lev@mandriva.org> 2.0.10-2mdv2011.0
+ Revision: 598119
- Bump release to force rebuild.
- Update to 2.0.10.

* Tue Nov 02 2010 Lev Givon <lev@mandriva.org> 2.0.8-1mdv2011.0
+ Revision: 592558
- import python-pyzmq


